==> qtjambi-debuginfo-windows-x64-6.5.4.jar: sources/QtJambiCore/QTimeZone_OffsetData_shell.cpp <==
#include <QtCore/QtGlobal>
#include <QtCore/qtimezone.h>
#include <QtCore/QVariant>

#include <QtJambi/QtJambiAPI>
#include <QtJambi/RegistryAPI>
#include <QtJambi/Cast>

void deleter_QTimeZone_OffsetData(void *ptr, bool isShell)
{
    QTJAMBI_NATIVE_METHOD_CALL("qtjambi_deleter for QTimeZone::OffsetData")
    QTimeZone::OffsetData *_ptr = reinterpret_cast<QTimeZone::OffsetData *>(ptr);
    if(!isShell){
        QtJambiAPI::registerNonShellDeletion(ptr);
    }
    delete _ptr;
}

// emitting (writeConstructors)
// new 
void __qt_construct_QTimeZone_OffsetData_0(void* __qtjambi_ptr, JNIEnv* __jni_env, jobject __jni_object, jvalue* __java_arguments)
{
    QTJAMBI_NATIVE_METHOD_CALL("construct ")
    Q_UNUSED(__java_arguments)
    QTimeZone::OffsetData *__qt_this = new(__qtjambi_ptr) QTimeZone::OffsetData();
    Q_UNUSED(__jni_object)
    Q_UNUSED(__jni_env)
    Q_UNUSED(__qt_this)
}

// destruct QTimeZone::OffsetData
void __qt_destruct_QTimeZone_OffsetData(void* ptr)
{
    QTJAMBI_NATIVE_METHOD_CALL("destruct QTimeZone::OffsetData")
    reinterpret_cast<QTimeZone::OffsetData*>(ptr)->~OffsetData();
}

// emitting  (functionsInTargetLang writeFinalFunction)
// QTimeZone::OffsetData::
extern "C" Q_DECL_EXPORT void JNICALL QTJAMBI_FUNCTION_PREFIX(Java_io_qt_core_QTimeZone_00024OffsetData_initialize_1native__Lio_qt_core_QTimeZone_00024OffsetData_2)
(JNIEnv *__jni_env,
 jclass __jni_class,
 jobject __jni_object)
{
    QTJAMBI_NATIVE_METHOD_CALL("QTimeZone::OffsetData::")
    QTJAMBI_TRY {
        QtJambiShell::initialize(__jni_env, __jni_class, __jni_object, &__qt_construct_QTimeZone_OffsetData_0, sizeof(QTimeZone::OffsetData), typeid(QTimeZone::OffsetData), false, &deleter_QTimeZone_OffsetData, nullptr);
    }QTJAMBI_CATCH(const JavaException& exn){
        exn.raiseInJava(__jni_env);
    }QTJAMBI_TRY_END

}

// emitting Field accessors (writeFieldAccessors)
extern "C" Q_DECL_EXPORT void JNICALL QTJAMBI_FUNCTION_PREFIX(Java_io_qt_core_QTimeZone_00024OffsetData_setAbbreviation_1native_1cref_1QString__JLjava_lang_String_2)
(JNIEnv *__jni_env,
 jobject __this,
 QtJambiNativeID __this_nativeId,
 jstring abbreviation0)
{
    QTJAMBI_TRY {
        Q_UNUSED(__this)
        QTimeZone::OffsetData *__qt_this = QtJambiAPI::objectFromNativeId<QTimeZone::OffsetData>(__this_nativeId);
        QtJambiAPI::checkNullPointer(__jni_env, __qt_this);
        QString  __qt_abbreviation0 = qtjambi_cast<QString>(__jni_env, abbreviation0);
        __qt_this->abbreviation = __qt_abbreviation0;
    }QTJAMBI_CATCH(const JavaException& exn){
        exn.raiseInJava(__jni_env);
    }QTJAMBI_TRY_END
}

extern "C" Q_DECL_EXPORT jstring JNICALL QTJAMBI_FUNCTION_PREFIX(Java_io_qt_core_QTimeZone_00024OffsetData_abbreviation_1native__J)
(JNIEnv *__jni_env,
 jobject __this,
 QtJambiNativeID __this_nativeId)
{
    jstring __java_return_value{0};
    QTJAMBI_TRY {
        Q_UNUSED(__this)
        QTimeZone::OffsetData *__qt_this = QtJambiAPI::objectFromNativeId<QTimeZone::OffsetData>(__this_nativeId);
        QtJambiAPI::checkNullPointer(__jni_env, __qt_this);
        const QString&  __qt_value = __qt_this->abbreviation;
        __java_return_value = qtjambi_cast<jstring>(__jni_env, __qt_value);
    }QTJAMBI_CATCH(const JavaException& exn){
        exn.raiseInJava(__jni_env);
    }QTJAMBI_TRY_END
    return __java_return_value;
}

extern "C" Q_DECL_EXPORT void JNICALL QTJAMBI_FUNCTION_PREFIX(Java_io_qt_core_QTimeZone_00024OffsetData_setAtUtc_1native_1cref_1QDateTime__JJ)
(JNIEnv *__jni_env,
 jobject __this,
 QtJambiNativeID __this_nativeId,
 QtJambiNativeID atUtc0)
{
    QTJAMBI_TRY {
        Q_UNUSED(__this)
        QTimeZone::OffsetData *__qt_this = QtJambiAPI::objectFromNativeId<QTimeZone::OffsetData>(__this_nativeId);
        QtJambiAPI::checkNullPointer(__jni_env, __qt_this);
        const QDateTime& __qt_atUtc0 = QtJambiAPI::valueReferenceFromNativeId<QDateTime>(atUtc0);
        __qt_this->atUtc = __qt_atUtc0;
    }QTJAMBI_CATCH(const JavaException& exn){
        exn.raiseInJava(__jni_env);
    }QTJAMBI_TRY_END
}

extern "C" Q_DECL_EXPORT jobject JNICALL QTJAMBI_FUNCTION_PREFIX(Java_io_qt_core_QTimeZone_00024OffsetData_atUtc_1native__J)
(JNIEnv *__jni_env,
 jobject __this,
 QtJambiNativeID __this_nativeId)
{
    jobject __java_return_value{0};
    QTJAMBI_TRY {
        Q_UNUSED(__this)
        QTimeZone::OffsetData *__qt_this = QtJambiAPI::objectFromNativeId<QTimeZone::OffsetData>(__this_nativeId);
        QtJambiAPI::checkNullPointer(__jni_env, __qt_this);
        const QDateTime&  __qt_value = __qt_this->atUtc;
        __java_return_value = qtjambi_cast<jobject>(__jni_env, __qt_value);
    }QTJAMBI_CATCH(const JavaException& exn){
        exn.raiseInJava(__jni_env);
    }QTJAMBI_TRY_END
    return __java_return_value;
}

extern "C" Q_DECL_EXPORT void JNICALL QTJAMBI_FUNCTION_PREFIX(Java_io_qt_core_QTimeZone_00024OffsetData_setDaylightTimeOffset_1native_1int__JI)
(JNIEnv *__jni_env,
 jobject __this,
 QtJambiNativeID __this_nativeId,
 jint daylightTimeOffset0)
{
    QTJAMBI_TRY {
        Q_UNUSED(__this)
        QTimeZone::OffsetData *__qt_this = QtJambiAPI::objectFromNativeId<QTimeZone::OffsetData>(__this_nativeId);
        QtJambiAPI::checkNullPointer(__jni_env, __qt_this);
        __qt_this->daylightTimeOffset = static_cast<int>(daylightTimeOffset0);
    }QTJAMBI_CATCH(const JavaException& exn){
        exn.raiseInJava(__jni_env);
    }QTJAMBI_TRY_END
}

extern "C" Q_DECL_EXPORT jint JNICALL QTJAMBI_FUNCTION_PREFIX(Java_io_qt_core_QTimeZone_00024OffsetData_daylightTimeOffset_1native__J)
(JNIEnv *__jni_env,
 jobject __this,
 QtJambiNativeID __this_nativeId)
{
    jint __java_return_value{0};
    QTJAMBI_TRY {
        Q_UNUSED(__this)
        QTimeZone::OffsetData *__qt_this = QtJambiAPI::objectFromNativeId<QTimeZone::OffsetData>(__this_nativeId);
        QtJambiAPI::checkNullPointer(__jni_env, __qt_this);
        int  __qt_value = __qt_this->daylightTimeOffset;
        __java_return_value = jint(__qt_value);
    }QTJAMBI_CATCH(const JavaException& exn){
        exn.raiseInJava(__jni_env);
    }QTJAMBI_TRY_END
    return __java_return_value;
}

extern "C" Q_DECL_EXPORT void JNICALL QTJAMBI_FUNCTION_PREFIX(Java_io_qt_core_QTimeZone_00024OffsetData_setOffsetFromUtc_1native_1int__JI)
(JNIEnv *__jni_env,
 jobject __this,
 QtJambiNativeID __this_nativeId,
 jint offsetFromUtc0)
{
    QTJAMBI_TRY {
        Q_UNUSED(__this)
        QTimeZone::OffsetData *__qt_this = QtJambiAPI::objectFromNativeId<QTimeZone::OffsetData>(__this_nativeId);
        QtJambiAPI::checkNullPointer(__jni_env, __qt_this);
        __qt_this->offsetFromUtc = static_cast<int>(offsetFromUtc0);
    }QTJAMBI_CATCH(const JavaException& exn){
        exn.raiseInJava(__jni_env);
    }QTJAMBI_TRY_END
}

extern "C" Q_DECL_EXPORT jint JNICALL QTJAMBI_FUNCTION_PREFIX(Java_io_qt_core_QTimeZone_00024OffsetData_offsetFromUtc_1native__J)
(JNIEnv *__jni_env,
 jobject __this,
 QtJambiNativeID __this_nativeId)
{
    jint __java_return_value{0};
    QTJAMBI_TRY {
        Q_UNUSED(__this)
        QTimeZone::OffsetData *__qt_this = QtJambiAPI::objectFromNativeId<QTimeZone::OffsetData>(__this_nativeId);
        QtJambiAPI::checkNullPointer(__jni_env, __qt_this);
        int  __qt_value = __qt_this->offsetFromUtc;
        __java_return_value = jint(__qt_value);
    }QTJAMBI_CATCH(const JavaException& exn){
        exn.raiseInJava(__jni_env);
    }QTJAMBI_TRY_END
    return __java_return_value;
}

extern "C" Q_DECL_EXPORT void JNICALL QTJAMBI_FUNCTION_PREFIX(Java_io_qt_core_QTimeZone_00024OffsetData_setStandardTimeOffset_1native_1int__JI)
(JNIEnv *__jni_env,
 jobject __this,
 QtJambiNativeID __this_nativeId,
 jint standardTimeOffset0)
{
    QTJAMBI_TRY {
        Q_UNUSED(__this)
        QTimeZone::OffsetData *__qt_this = QtJambiAPI::objectFromNativeId<QTimeZone::OffsetData>(__this_nativeId);
        QtJambiAPI::checkNullPointer(__jni_env, __qt_this);
        __qt_this->standardTimeOffset = static_cast<int>(standardTimeOffset0);
    }QTJAMBI_CATCH(const JavaException& exn){
        exn.raiseInJava(__jni_env);
    }QTJAMBI_TRY_END
}

extern "C" Q_DECL_EXPORT jint JNICALL QTJAMBI_FUNCTION_PREFIX(Java_io_qt_core_QTimeZone_00024OffsetData_standardTimeOffset_1native__J)
(JNIEnv *__jni_env,
 jobject __this,
 QtJambiNativeID __this_nativeId)
{
    jint __java_return_value{0};
    QTJAMBI_TRY {
        Q_UNUSED(__this)
        QTimeZone::OffsetData *__qt_this = QtJambiAPI::objectFromNativeId<QTimeZone::OffsetData>(__this_nativeId);
        QtJambiAPI::checkNullPointer(__jni_env, __qt_this);
        int  __qt_value = __qt_this->standardTimeOffset;
        __java_return_value = jint(__qt_value);
    }QTJAMBI_CATCH(const JavaException& exn){
        exn.raiseInJava(__jni_env);
    }QTJAMBI_TRY_END
    return __java_return_value;
}

// emitting (writeJavaLangObjectOverrideFunctions)
// emitting (writeCloneFunction)

extern "C" Q_DECL_EXPORT jobject JNICALL QTJAMBI_FUNCTION_PREFIX(Java_io_qt_core_QTimeZone_00024OffsetData_clone_1native)
(JNIEnv *__jni_env, jobject, QtJambiNativeID __this_nativeId)
{
    jobject __java_return_value = nullptr;
    QTJAMBI_TRY {
        const QTimeZone::OffsetData *__qt_this = QtJambiAPI::objectFromNativeId<QTimeZone::OffsetData>(__this_nativeId);
        QtJambiAPI::checkNullPointer(__jni_env, __qt_this);
        __java_return_value = qtjambi_cast<jobject>(__jni_env, *__qt_this);
    } QTJAMBI_CATCH(const JavaException& exn){
        exn.raiseInJava(__jni_env);
    } QTJAMBI_TRY_END
    return __java_return_value;
}


void initialize_meta_info_QTimeZone_OffsetData(){
    using namespace RegistryAPI;
    const std::type_info& typeId = registerValueTypeInfo<QTimeZone::OffsetData>("QTimeZone::OffsetData", "io/qt/core/QTimeZone$OffsetData");
    Q_UNUSED(typeId)
// BEGIN: function table
    registerConstructorInfos(typeId, &__qt_destruct_QTimeZone_OffsetData, {
        ConstructorInfo(&__qt_construct_QTimeZone_OffsetData_0, nullptr)
    });
// END: function table

// BEGIN: type registration
    registerDeleter(typeId, &deleter_QTimeZone_OffsetData);
    registerMetaType<QTimeZone::OffsetData>("QTimeZone::OffsetData");
// END: type registration

// BEGIN: polymorphic ids
// END: polymorphic ids


// BEGIN: enums and flags
// END: enums and flags
}

==> qtjambi-debuginfo-windows-x64-6.6.3.jar: sources/QtJambiCore/QTimeZone_OffsetData_shell.cpp <==
#include <QtCore/QtGlobal>
#include <QtCore/qtimezone.h>
#include <QtCore/QVariant>
#include <QtCore/qdatetime.h>

#include <QtJambi/QtJambiAPI>
#include <QtJambi/RegistryAPI>
#include <QtJambi/Cast>

void deleter_QTimeZone_OffsetData(void *ptr, bool isShell)
{
    QTJAMBI_NATIVE_METHOD_CALL("qtjambi_deleter for QTimeZone::OffsetData")
    QTimeZone::OffsetData *_ptr = reinterpret_cast<QTimeZone::OffsetData *>(ptr);
    if(!isShell){
        QtJambiAPI::registerNonShellDeletion(ptr);
    }
    delete _ptr;
}

// emitting (writeConstructors)
// new OffsetData()
void __qt_construct_QTimeZone_OffsetData(void* __qtjambi_ptr, JNIEnv* __jni_env, jobject __jni_object, jvalue* __java_arguments, bool __qtjambi_is_generic)
{
    QTJAMBI_NATIVE_METHOD_CALL("construct OffsetData()")
    Q_UNUSED(__java_arguments)
    QTimeZone::OffsetData *__qt_this = new(__qtjambi_ptr) QTimeZone::OffsetData();
    Q_UNUSED(__qtjambi_is_generic)
    Q_UNUSED(__jni_object)
    Q_UNUSED(__jni_env)
    Q_UNUSED(__qt_this)
}

// QTimeZone::OffsetData::OffsetData()
extern "C" Q_DECL_EXPORT void JNICALL QTJAMBI_FUNCTION_PREFIX(Java_io_qt_core_QTimeZone_00024OffsetData_initialize_1native__Lio_qt_core_QTimeZone_00024OffsetData_2)
(JNIEnv *__jni_env,
 jclass __jni_class,
 jobject __jni_object)
{
    QTJAMBI_NATIVE_METHOD_CALL("QTimeZone::OffsetData::OffsetData()")
    QTJAMBI_TRY {
        QtJambiShell::initialize(__jni_env, __jni_class, __jni_object, &__qt_construct_QTimeZone_OffsetData, sizeof(QTimeZone::OffsetData), typeid(QTimeZone::OffsetData), false, &deleter_QTimeZone_OffsetData, nullptr);
    }QTJAMBI_CATCH(const JavaException& exn){
        exn.raiseInJava(__jni_env);
    }QTJAMBI_TRY_END

}

// new OffsetData(QTimeZone::OffsetData)
void __qt_construct_QTimeZone_OffsetData_cref_QTimeZone_OffsetData(void* __qtjambi_ptr, JNIEnv* __jni_env, jobject __jni_object, jvalue* __java_arguments, bool __qtjambi_is_generic)
{
    QTJAMBI_NATIVE_METHOD_CALL("construct OffsetData(QTimeZone::OffsetData)")
    jobject other0 = __java_arguments[0].l;
    const QTimeZone::OffsetData& __qt_other0 = qtjambi_cast<const QTimeZone::OffsetData& >(__jni_env, other0);
    QTimeZone::OffsetData *__qt_this = new(__qtjambi_ptr) QTimeZone::OffsetData(__qt_other0);
    Q_UNUSED(__qtjambi_is_generic)
    Q_UNUSED(__jni_object)
    Q_UNUSED(__qt_this)
}

// QTimeZone::OffsetData::OffsetData(QTimeZone::OffsetData)
extern "C" Q_DECL_EXPORT void JNICALL QTJAMBI_FUNCTION_PREFIX(Java_io_qt_core_QTimeZone_00024OffsetData_initialize_1native__Lio_qt_core_QTimeZone_00024OffsetData_2Lio_qt_core_QTimeZone_00024OffsetData_2)
(JNIEnv *__jni_env,
 jclass __jni_class,
 jobject __jni_object,
 jobject other0)
{
    QTJAMBI_NATIVE_METHOD_CALL("QTimeZone::OffsetData::OffsetData(QTimeZone::OffsetData)")
    QTJAMBI_TRY {
        jvalue arguments;
        arguments.l = other0;
        QtJambiShell::initialize(__jni_env, __jni_class, __jni_object, &__qt_construct_QTimeZone_OffsetData_cref_QTimeZone_OffsetData, sizeof(QTimeZone::OffsetData), typeid(QTimeZone::OffsetData), false, &deleter_QTimeZone_OffsetData, &arguments);
    }QTJAMBI_CATCH(const JavaException& exn){
        exn.raiseInJava(__jni_env);
    }QTJAMBI_TRY_END

}

// new OffsetData{QString,QDateTime,int,int,int}
void __qt_construct_QTimeZone_OffsetData_QString_QDateTime_int_int_int(void* __qtjambi_ptr, JNIEnv* __jni_env, jobject __jni_object, jvalue* __java_arguments, bool __qtjambi_is_generic)
{
    QTJAMBI_NATIVE_METHOD_CALL("construct OffsetData{QString,QDateTime,int,int,int}")
    jstring abbreviation0 = static_cast<jstring>(__java_arguments[0].l);
    QString  __qt_abbreviation0 = qtjambi_cast<QString>(__jni_env, abbreviation0);
    jobject atUtc1 = __java_arguments[1].l;
    QDateTime __qt_atUtc1 = qtjambi_cast<QDateTime >(__jni_env, atUtc1);
    jint offsetFromUtc2 = __java_arguments[2].i;
    Q_UNUSED(offsetFromUtc2)
    jint standardTimeOffset3 = __java_arguments[3].i;
    Q_UNUSED(standardTimeOffset3)
    jint daylightTimeOffset4 = __java_arguments[4].i;
    Q_UNUSED(daylightTimeOffset4)
    QTimeZone::OffsetData *__qt_this = new(__qtjambi_ptr) QTimeZone::OffsetData{__qt_abbreviation0, __qt_atUtc1, static_cast<int>(offsetFromUtc2), static_cast<int>(standardTimeOffset3), static_cast<int>(daylightTimeOffset4)};
    Q_UNUSED(__qtjambi_is_generic)
    Q_UNUSED(__jni_object)
    Q_UNUSED(__qt_this)
}

// QTimeZone::OffsetData::OffsetData{QString,QDateTime,int,int,int}
extern "C" Q_DECL_EXPORT void JNICALL QTJAMBI_FUNCTION_PREFIX(Java_io_qt_core_QTimeZone_00024OffsetData_initialize_1native__Lio_qt_core_QTimeZone_00024OffsetData_2Ljava_lang_String_2Lio_qt_core_QDateTime_2III)
(JNIEnv *__jni_env,
 jclass __jni_class,
 jobject __jni_object,
 jstring abbreviation0,
 jobject atUtc1,
 jint offsetFromUtc2,
 jint standardTimeOffset3,
 jint daylightTimeOffset4)
{
    QTJAMBI_NATIVE_METHOD_CALL("QTimeZone::OffsetData::OffsetData{QString,QDateTime,int,int,int}")
    QTJAMBI_TRY {
        jvalue arguments[5];
        arguments[0].l = abbreviation0;
        arguments[1].l = atUtc1;
        arguments[2].i = offsetFromUtc2;
        arguments[3].i = standardTimeOffset3;
        arguments[4].i = daylightTimeOffset4;
        QtJambiShell::initialize(__jni_env, __jni_class, __jni_object, &__qt_construct_QTimeZone_OffsetData_QString_QDateTime_int_int_int, sizeof(QTimeZone::OffsetData), typeid(QTimeZone::OffsetData), false, &deleter_QTimeZone_OffsetData, arguments);
    }QTJAMBI_CATCH(const JavaException& exn){
        exn.raiseInJava(__jni_env);
    }QTJAMBI_TRY_END

}

// destruct QTimeZone::OffsetData
void __qt_destruct_QTimeZone_OffsetData(void* ptr)
{
    QTJAMBI_NATIVE_METHOD_CALL("destruct QTimeZone::OffsetData")
    reinterpret_cast<QTimeZone::OffsetData*>(ptr)->~OffsetData();
}

// emitting  (functionsInTargetLang writeFinalFunction)
// emitting Field accessors (writeFieldAccessors)
extern "C" Q_DECL_EXPORT void JNICALL QTJAMBI_FUNCTION_PREFIX(Java_io_qt_core_QTimeZone_00024OffsetData_setAbbreviation_1native_1cref_1QString__JLjava_lang_String_2)
(JNIEnv *__jni_env,
 jobject __this,
 QtJambiNativeID __this_nativeId,
 jstring abbreviation0)
{
    QTJAMBI_TRY {
        Q_UNUSED(__this)
        QTimeZone::OffsetData *__qt_this = QtJambiAPI::objectFromNativeId<QTimeZone::OffsetData>(__this_nativeId);
        QtJambiAPI::checkNullPointer(__jni_env, __qt_this);
        QString  __qt_abbreviation0 = qtjambi_cast<QString>(__jni_env, abbreviation0);
        __qt_this->abbreviation = __qt_abbreviation0;
    }QTJAMBI_CATCH(const JavaException& exn){
        exn.raiseInJava(__jni_env);
    }QTJAMBI_TRY_END
}

extern "C" Q_DECL_EXPORT jstring JNICALL QTJAMBI_FUNCTION_PREFIX(Java_io_qt_core_QTimeZone_00024OffsetData_abbreviation_1native__J)
(JNIEnv *__jni_env,
 jobject __this,
 QtJambiNativeID __this_nativeId)
{
    jstring __java_return_value{0};
    QTJAMBI_TRY {
        Q_UNUSED(__this)
        QTimeZone::OffsetData *__qt_this = QtJambiAPI::objectFromNativeId<QTimeZone::OffsetData>(__this_nativeId);
        QtJambiAPI::checkNullPointer(__jni_env, __qt_this);
        const QString&  __qt_value = __qt_this->abbreviation;
        __java_return_value = qtjambi_cast<jstring>(__jni_env, __qt_value);
    }QTJAMBI_CATCH(const JavaException& exn){
        exn.raiseInJava(__jni_env);
    }QTJAMBI_TRY_END
    return __java_return_value;
}

extern "C" Q_DECL_EXPORT void JNICALL QTJAMBI_FUNCTION_PREFIX(Java_io_qt_core_QTimeZone_00024OffsetData_setAtUtc_1native_1cref_1QDateTime__JJ)
(JNIEnv *__jni_env,
 jobject __this,
 QtJambiNativeID __this_nativeId,
 QtJambiNativeID atUtc0)
{
    QTJAMBI_TRY {
        Q_UNUSED(__this)
        QTimeZone::OffsetData *__qt_this = QtJambiAPI::objectFromNativeId<QTimeZone::OffsetData>(__this_nativeId);
        QtJambiAPI::checkNullPointer(__jni_env, __qt_this);
        const QDateTime& __qt_atUtc0 = QtJambiAPI::valueReferenceFromNativeId<QDateTime>(atUtc0);
        __qt_this->atUtc = __qt_atUtc0;
    }QTJAMBI_CATCH(const JavaException& exn){
        exn.raiseInJava(__jni_env);
    }QTJAMBI_TRY_END
}

extern "C" Q_DECL_EXPORT jobject JNICALL QTJAMBI_FUNCTION_PREFIX(Java_io_qt_core_QTimeZone_00024OffsetData_atUtc_1native__J)
(JNIEnv *__jni_env,
 jobject __this,
 QtJambiNativeID __this_nativeId)
{
    jobject __java_return_value{0};
    QTJAMBI_TRY {
        Q_UNUSED(__this)
        QTimeZone::OffsetData *__qt_this = QtJambiAPI::objectFromNativeId<QTimeZone::OffsetData>(__this_nativeId);
        QtJambiAPI::checkNullPointer(__jni_env, __qt_this);
        const QDateTime&  __qt_value = __qt_this->atUtc;
        __java_return_value = qtjambi_cast<jobject>(__jni_env, __qt_value);
    }QTJAMBI_CATCH(const JavaException& exn){
        exn.raiseInJava(__jni_env);
    }QTJAMBI_TRY_END
    return __java_return_value;
}

extern "C" Q_DECL_EXPORT void JNICALL QTJAMBI_FUNCTION_PREFIX(Java_io_qt_core_QTimeZone_00024OffsetData_setDaylightTimeOffset_1native_1int__JI)
(JNIEnv *__jni_env,
 jobject __this,
 QtJambiNativeID __this_nativeId,
 jint daylightTimeOffset0)
{
    QTJAMBI_TRY {
        Q_UNUSED(__this)
        QTimeZone::OffsetData *__qt_this = QtJambiAPI::objectFromNativeId<QTimeZone::OffsetData>(__this_nativeId);
        QtJambiAPI::checkNullPointer(__jni_env, __qt_this);
        __qt_this->daylightTimeOffset = static_cast<int>(daylightTimeOffset0);
    }QTJAMBI_CATCH(const JavaException& exn){
        exn.raiseInJava(__jni_env);
    }QTJAMBI_TRY_END
}

extern "C" Q_DECL_EXPORT jint JNICALL QTJAMBI_FUNCTION_PREFIX(Java_io_qt_core_QTimeZone_00024OffsetData_daylightTimeOffset_1native__J)
(JNIEnv *__jni_env,
 jobject __this,
 QtJambiNativeID __this_nativeId)
{
    jint __java_return_value{0};
    QTJAMBI_TRY {
        Q_UNUSED(__this)
        QTimeZone::OffsetData *__qt_this = QtJambiAPI::objectFromNativeId<QTimeZone::OffsetData>(__this_nativeId);
        QtJambiAPI::checkNullPointer(__jni_env, __qt_this);
        int  __qt_value = __qt_this->daylightTimeOffset;
        __java_return_value = jint(__qt_value);
    }QTJAMBI_CATCH(const JavaException& exn){
        exn.raiseInJava(__jni_env);
    }QTJAMBI_TRY_END
    return __java_return_value;
}

extern "C" Q_DECL_EXPORT void JNICALL QTJAMBI_FUNCTION_PREFIX(Java_io_qt_core_QTimeZone_00024OffsetData_setOffsetFromUtc_1native_1int__JI)
(JNIEnv *__jni_env,
 jobject __this,
 QtJambiNativeID __this_nativeId,
 jint offsetFromUtc0)
{
    QTJAMBI_TRY {
        Q_UNUSED(__this)
        QTimeZone::OffsetData *__qt_this = QtJambiAPI::objectFromNativeId<QTimeZone::OffsetData>(__this_nativeId);
        QtJambiAPI::checkNullPointer(__jni_env, __qt_this);
        __qt_this->offsetFromUtc = static_cast<int>(offsetFromUtc0);
    }QTJAMBI_CATCH(const JavaException& exn){
        exn.raiseInJava(__jni_env);
    }QTJAMBI_TRY_END
}

extern "C" Q_DECL_EXPORT jint JNICALL QTJAMBI_FUNCTION_PREFIX(Java_io_qt_core_QTimeZone_00024OffsetData_offsetFromUtc_1native__J)
(JNIEnv *__jni_env,
 jobject __this,
 QtJambiNativeID __this_nativeId)
{
    jint __java_return_value{0};
    QTJAMBI_TRY {
        Q_UNUSED(__this)
        QTimeZone::OffsetData *__qt_this = QtJambiAPI::objectFromNativeId<QTimeZone::OffsetData>(__this_nativeId);
        QtJambiAPI::checkNullPointer(__jni_env, __qt_this);
        int  __qt_value = __qt_this->offsetFromUtc;
        __java_return_value = jint(__qt_value);
    }QTJAMBI_CATCH(const JavaException& exn){
        exn.raiseInJava(__jni_env);
    }QTJAMBI_TRY_END
    return __java_return_value;
}

extern "C" Q_DECL_EXPORT void JNICALL QTJAMBI_FUNCTION_PREFIX(Java_io_qt_core_QTimeZone_00024OffsetData_setStandardTimeOffset_1native_1int__JI)
(JNIEnv *__jni_env,
 jobject __this,
 QtJambiNativeID __this_nativeId,
 jint standardTimeOffset0)
{
    QTJAMBI_TRY {
        Q_UNUSED(__this)
        QTimeZone::OffsetData *__qt_this = QtJambiAPI::objectFromNativeId<QTimeZone::OffsetData>(__this_nativeId);
        QtJambiAPI::checkNullPointer(__jni_env, __qt_this);
        __qt_this->standardTimeOffset = static_cast<int>(standardTimeOffset0);
    }QTJAMBI_CATCH(const JavaException& exn){
        exn.raiseInJava(__jni_env);
    }QTJAMBI_TRY_END
}

extern "C" Q_DECL_EXPORT jint JNICALL QTJAMBI_FUNCTION_PREFIX(Java_io_qt_core_QTimeZone_00024OffsetData_standardTimeOffset_1native__J)
(JNIEnv *__jni_env,
 jobject __this,
 QtJambiNativeID __this_nativeId)
{
    jint __java_return_value{0};
    QTJAMBI_TRY {
        Q_UNUSED(__this)
        QTimeZone::OffsetData *__qt_this = QtJambiAPI::objectFromNativeId<QTimeZone::OffsetData>(__this_nativeId);
        QtJambiAPI::checkNullPointer(__jni_env, __qt_this);
        int  __qt_value = __qt_this->standardTimeOffset;
        __java_return_value = jint(__qt_value);
    }QTJAMBI_CATCH(const JavaException& exn){
        exn.raiseInJava(__jni_env);
    }QTJAMBI_TRY_END
    return __java_return_value;
}

// emitting (writeJavaLangObjectOverrideFunctions)
// emitting (writeCloneFunction)

extern "C" Q_DECL_EXPORT jobject JNICALL QTJAMBI_FUNCTION_PREFIX(Java_io_qt_core_QTimeZone_00024OffsetData_clone_1native)
(JNIEnv *__jni_env, jobject, QtJambiNativeID __this_nativeId)
{
    jobject __java_return_value = nullptr;
    QTJAMBI_TRY {
        const QTimeZone::OffsetData *__qt_this = QtJambiAPI::objectFromNativeId<QTimeZone::OffsetData>(__this_nativeId);
        QtJambiAPI::checkNullPointer(__jni_env, __qt_this);
        __java_return_value = qtjambi_cast<jobject>(__jni_env, *__qt_this);
    } QTJAMBI_CATCH(const JavaException& exn){
        exn.raiseInJava(__jni_env);
    } QTJAMBI_TRY_END
    return __java_return_value;
}


void initialize_meta_info_QTimeZone_OffsetData(){
    using namespace RegistryAPI;
    const std::type_info& typeId = registerValueTypeInfo<QTimeZone::OffsetData>("QTimeZone::OffsetData", "io/qt/core/QTimeZone$OffsetData");
    Q_UNUSED(typeId)
// BEGIN: function table
    registerConstructorInfos(typeId, &__qt_destruct_QTimeZone_OffsetData, {
        ConstructorInfo(&__qt_construct_QTimeZone_OffsetData, nullptr)
       ,ConstructorInfo(&__qt_construct_QTimeZone_OffsetData_cref_QTimeZone_OffsetData, "Lio/qt/core/QTimeZone$OffsetData;")
       ,ConstructorInfo(&__qt_construct_QTimeZone_OffsetData_QString_QDateTime_int_int_int, "Ljava/lang/String;Lio/qt/core/QDateTime;III")
    });
// END: function table

// BEGIN: type registration
    registerDeleter(typeId, &deleter_QTimeZone_OffsetData);
    registerMetaType<QTimeZone::OffsetData>("QTimeZone::OffsetData");
// END: type registration

// BEGIN: polymorphic ids
// END: polymorphic ids


// BEGIN: enums and flags
// END: enums and flags
}
